/*

  sshadt_bag_i.h

  Author: Antti Huima <huima@ssh.fi>

  Copyright (c) 1999 SSH Communications Security, Finland
  All rights reserved.

  Created Fri Sep 24 13:24:53 1999.

  */


#include "sshadt_map_i.h"

/* 'bag' shares implementation with 'map'.  It simply does not use the
   extra void pointer for storing the map value. */
